@@ -26,6 +26,10 @@ library(DescTools)
 # })
 # 
 
+set.seed(45)
+(z <- as.numeric(names(w <- table(x <- sample(-10:20, size=50, r=T)))))
+w
+
 stopifnot(all(
   identical(Mode(5), structure(5, freq = 1L))
   , identical(Mode(NA), structure(NA_real_, freq = NA_integer_)) 
@@ -35,5 +39,21 @@ stopifnot(all(
   , identical(Mode(c(NA, 0:5, 5), na.rm=TRUE), structure(5, freq = 2L)) 
   , identical(Mode(c(0:5, 4, 5, 6)), structure(c(4, 5), freq = 2L)) 
   , identical(Mode(c(0:8, rep(c(1,3, 8), each=5))), structure(c(1, 3, 8), freq = 6L)) 
+  
+  , all.equal(Kurt(x = z, weights = w, method = 1), Kurt(x = x, method = 1))
+  , all.equal(Kurt(x = z, weights = w, method = 2), Kurt(x = x, method = 2))
+  , all.equal(Kurt(x = z, weights = w, method = 3), Kurt(x = x, method = 3))
+  
+  , all.equal(Skew(x = z, weights = w, method = 1), Skew(x = x, method = 1))
+  , all.equal(Skew(x = z, weights = w, method = 2), Skew(x = x, method = 2))
+  , all.equal(Skew(x = z, weights = w, method = 3), Skew(x = x, method = 3))
+  
+  , all.equal(CoefVar(z, weights = w, unbiased = TRUE), CoefVar(x, unbiased = TRUE))
+  , all.equal(CoefVar(z, weights = w, unbiased = FALSE), CoefVar(x, unbiased = FALSE))
+  
+  , all.equal(MeanAD(x), MeanAD(z, w))
+  , all.equal(MeanAD(x, center = Median), MeanAD(z, w, center = Median))
+  , all.equal(MeanAD(x, center = 7), MeanAD(z, w, center = 7))
+  
 ))
 
